@@ -127,7 +127,7 @@ class WorkflowManager(object):
         """
         return self._data[index]
 
-    def load(self, instruction, pathname=None):
+    def load(self, instruction='pieces', pathname=None):
         """
         Import analysis data from long-term storage on a filesystem. This should primarily be \
         used for the ``u'pieces'`` instruction, to control when the initial music21 import \
@@ -139,9 +139,7 @@ class WorkflowManager(object):
         .. note:: If one of the files imports as a :class:`music21.stream.Opus`, the number of
             pieces and their order *will* change.
 
-        Parameters
-        ==========
-        :parameter instruction: The type of data to load.
+        :parameter instruction: The type of data to load. Defaults to ``'pieces'``.
         :type instruction: basestring
         :parameter pathname: The pathname of the data to import; not required for the \
             ``u'pieces'`` instruction.
@@ -699,11 +697,24 @@ class WorkflowManager(object):
         # run additional indexers for annotation
         for i in xrange(len(self._data)):
             ann_p = []
+            combos = []
+            if 'all' == self.settings(i, 'voice combinations'):
+                lowest_part = len(self.metadata(i, 'parts')) - 1
+                combos = [[x, lowest_part] for x in xrange(lowest_part)]
+            elif 'all pairs' == self.settings(i, 'voice combinations'):
+                # Calculate all 2-part combinations. We must do this in the same order as the
+                # IntervalIndexer, or else the labels will be wrong.
+                for left in xrange(len(self.metadata(i, 'parts'))):
+                    for right in xrange(left + 1, len(self.metadata(i, 'parts'))):
+                        combos.append([left, right])
+            else:
+                combos = ast.literal_eval(self.settings(i, 'voice combinations'))
             for j in xrange(len(self._result[i])):
+                setts = {'part_names': combos}
                 ann_p.append(self._data[i].get_data([lilypond.AnnotationIndexer,
                                                      lilypond.AnnotateTheNoteIndexer,
                                                      lilypond.PartNotesIndexer],
-                                                    None,
+                                                    setts,
                                                     [self._result[i][j]])[0])
             annotation_parts.append(ann_p)
         # run OutputLilyPond and LilyPond
